@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.108_01';
+our $VERSION = '0.108_02';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Wed Oct 10 14:19:06 2018 GMT
+# on Sat Oct 13 18:41:14 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1733,7 +1733,7 @@ __PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-0
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
-__PACKAGE__->status( add => 25170, iridium => '-', 'Iridium 56', 'Tumbling' );
+__PACKAGE__->status( add => 25170, iridium => 'D', 'Iridium 56', 'Decayed 2018-10-11' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
 __PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
@@ -1753,7 +1753,7 @@ __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-0
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
 __PACKAGE__->status( add => 25320, iridium => '-', 'Iridium 71', 'Tumbling' );
-__PACKAGE__->status( add => 25342, iridium => '-', 'Iridium 70', 'Tumbling' );
+__PACKAGE__->status( add => 25342, iridium => 'D', 'Iridium 70', 'Decayed 2018-10-11' );
 __PACKAGE__->status( add => 25343, iridium => 'D', 'Iridium 72', 'Decayed 2018-05-14' );
 __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
@@ -1770,7 +1770,7 @@ __PACKAGE__->status( add => 25528, iridium => 'D', 'Iridium 86', 'Decayed 2018-1
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
 __PACKAGE__->status( add => 25530, iridium => '-', 'Iridium 84', 'Tumbling' );
 __PACKAGE__->status( add => 25531, iridium => 'S', 'Iridium 83', '' );
-__PACKAGE__->status( add => 25577, iridium => 'S', 'Iridium 20', '' );
+__PACKAGE__->status( add => 25577, iridium => '-', 'Iridium 20', 'Tumbling' );
 __PACKAGE__->status( add => 25578, iridium => '-', 'Iridium 11', 'Tumbling' );
 __PACKAGE__->status( add => 25777, iridium => '+', 'Iridium 14', '' );
 __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-05-24' );
@@ -1784,9 +1784,9 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 
 # Summary:
 # Operational [+]: 9
-#       Spare [S]: 10
-#    Tumbling [-]: 38
-#     Decayed [D]: 40
+#       Spare [S]: 9
+#    Tumbling [-]: 37
+#     Decayed [D]: 42
 
 1;
 
